Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AnyResult ¶ added in v0.0.2
type AnyResult interface {
Any() Result[any] // The Any method returns a Result[any] that can be used with any type.
}
AnyResult can be used with any Result.
type Result ¶
type Result[R any] interface { AnyResult V() (R, error) // The V method returns the final value or an error. Value() R // The Value method returns the final value. Err() error // The Err method returns the error. }
Result defines the interface for returning results from asynchronous operations. It encapsulates the final value or error from the operation.
Click to show internal directories.
Click to hide internal directories.